"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultMessageRetryStrategy = void 0;
/**
 * Get the default message retry strategy. This strategy checks that the maximum
 * of finished attempts is not exceeded. The number can be defined in the
 * `config.settings.maxAttempts` variable. If the error is a PostgreSQL
 * serialization error it will always be retried. If another error was thrown
 * from the code handling errors in the error handler the message is not retired.
 */
const defaultMessageRetryStrategy = (config) => {
    return (message, error, source) => {
        if (error.innerError &&
            'code' in error.innerError &&
            error.innerError.code === '40001') {
            // always retry PostgreSQL serialization_failure
            return true;
        }
        if (source === 'error-handler-error') {
            // If even the code that handles errors in the error handler throws an error the message is not retried.
            return false;
        }
        return message.finishedAttempts < config.settings.maxAttempts;
    };
};
exports.defaultMessageRetryStrategy = defaultMessageRetryStrategy;
//# sourceMappingURL=message-retry-strategy.js.map